@@ -9,6 +9,8 @@ from properly_util_python.properly_logging import ProperLogger
 
 class ProperlyEvents(str, Enum):
     USER_CREATED = 'userCreated'
+    USER_CITY_UPDATED = 'userCityUpdated'
+    USER_ALERT_UNSUBSCRIBED = 'userAlertUnsubscribed'
     STAGE_CHANGED_OFFER = 'stageChangedOffer'
     USER_ENTERED_ALL_OFFER_INFO = 'userEnteredAllOfferInfo'
     SHOWING_UPDATED_OR_CREATED = 'userShowingUpdatedOrCreated'
@@ -16,6 +18,7 @@ class ProperlyEvents(str, Enum):
     DEAL_CHANGED_STAGE = 'dealChangedStage'
     ACCEPTED_OFFER = 'userAcceptedOffer'
     SEARCH_RESULTS_CHANGED = 'searchResultsChanged'
+    RECOMMENDATION_RESULTS_CHANGED = 'recommendationResultsChanged'
     PPR_FEEDBACK = 'pprFeedback'
     FAVOURITE_ADDED = 'favouriteAdded'
     FAVOURITE_REMOVED = 'favouriteRemoved'
