@@ -82,3 +82,16 @@ def deploy(c, stage=None):
         return
 
     c.run(f"./node_modules/serverless/bin/serverless.js deploy --stage {stage}")
+
+
+@task()
+def shutdown(c, stage=None):
+    """
+    Run the serverless remove. This will shut down the service. Make sure it can be deprecated before executing.
+    --stage : stage to deploy to
+    """
+    if not stage:
+        print("must supply a stage, one of dev, staging, prod")
+        return
+
+    c.run(f"./node_modules/serverless/bin/serverless.js remove --stage {stage}")
